#
# spec file for package python-sparse
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-sparse
Version:        0.3.1
Release:        3.2
Summary:        Sparse n-dimensional arrays for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/pydata/sparse
Source:         https://files.pythonhosted.org/packages/source/s/sparse/sparse-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.13}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 0.19}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.13
Requires:       python-scipy >= 0.19
BuildArch:      noarch

%python_subpackages

%description
This module implements sparse multidimensional arrays on top of NumPy and
Scipy.sparse. It generalizes the scipy.sparse.coo_matrix layout, but
extends beyond just rows and columns to an arbitrary number of
dimensions.

The original motivation is for machine learning algorithms, but it is
intended for somewhat general use.

%prep
%setup -q -n sparse-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# setup.cfg enables some pytest backends we don't want
mv setup.cfg old_setup.cfg_old
%{python_expand export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{$python_sitelib}
py.test-%{$python_bin_suffix} sparse
}
mv old_setup.cfg_old setup.cfg

%files %{python_files}
%doc README.rst
%license LICENSE.rst
%{python_sitelib}/*

%changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Update descriptions.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.3.1
  * Add Elementwise broadcasting and broadcast_to (:pr:`35`) `Hameer Abbasi`_
  * Add Bitwise ops (:pr:`38`) `Hameer Abbasi`_
  * Add slicing support for Ellipsis and None (:pr:`37`) `Matthew Rocklin`_
  * Add triu and tril and tests (:pr:`40`) `Hameer Abbasi`_
  * Extend gitignore file  (:pr:`42`) `Nils Werner`_
  * Update MANIFEST.in (:pr:`45`) `Matthew Rocklin`_
  * Remove auto densification and unify operator code (:pr:`46`) `Hameer Abbasi`_
  * Fix nnz for scalars (:pr:`48`) `Hameer Abbasi`_
  * Update README (:pr:`50`) (:pr:`53`) `Hameer Abbasi`_
  * Fix large concatenations and stacks (:pr:`50`) `Hameer Abbasi`_
  * Add __array_ufunc__ for __call__ and reduce (:pr:`49`) `Hameer Abbasi`_
  * Update documentation (:pr:`54`) `Hameer Abbasi`_
  * Flake8 and coverage in pytest (:pr:`59`) `Nils Werner`_
  * Copy constructor (:pr:`55`) `Nils Werner`_
  * Add random function (:pr:`41`) `Nils Werner`_
  * Add lots of indexing features (:pr:`57`) `Hameer Abbasi`_
  * Validate .transpose axes (:pr:`61`) `Nils Werner`_
  * Simplify axes normalization logic `Nils Werner`_
  * User higher density for sparse.random in tests (:pr:`64`) `Keisuke Fujii`_
  * Support left-side np.number elemwise operations (:pr:`67`) `Keisuke Fujii`_
  * Support len on COO (:pr:`68`) `Nils Werner`_
  * Update scipy version in requirements (:pr:`70`) `Hameer Abbasi`_
  * Documentation (:pr:`43`) `Nils Werner`_ and `Hameer Abbasi`_
  * Use Tox for cross Python-version testing (:pr:`77`) `Nils Werner`_
  * Support mixed sparse-dense when result is sparse (:pr:`75`) `Hameer Abbasi`_
  * Update contributing.rst (:pr:`76`) `Hameer Abbasi`_
  * Size and density properties (:pr:`69`) `Nils Werner`_
  * Fix large sum (:pr:`83`) `Hameer Abbasi`_
  * Add DOK (:pr:`85`) `Hameer Abbasi`_
  * Implement __array__ protocol (:pr:`87`) `Matthew Rocklin`_
- spec file cleanups
* Thu Nov  2 2017 arun@gmx.de
- update to version 0.1.1:
  * Add @ operator (simplify) (#16)
  * Opt in to caching
  * Cache reshape and transpose
  * Add tocsr method and sorted checking
  * Fix windows errors around int/long
  * use elemwise_binary in __add__
  * Fix bug in large reductions
  * Add out= keywords to ufuncs
* Thu May 25 2017 toddrme2178@gmail.com
- Initial version
